<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sv-SE" sourcelanguage="en">
  <context>
    <name>CmdDrawingAnnotation</name>
    <message>
      <location filename="../../Command.cpp" line="+389"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Annotation</source>
      <translation>&amp;Annotering</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Inserts an Annotation view in the active drawing</source>
      <translation>Infogar en annoteringsvy i den aktiva ritningen</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingClip</name>
    <message>
      <location line="+41"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Clip</source>
      <translation>&amp;Klipp</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Inserts a clip group in the active drawing</source>
      <translation>Infogar en Klipp-grupp i den aktiva ritningen</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingExportPage</name>
    <message>
      <location line="+91"/>
      <source>File</source>
      <translation>Fil</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Export page...</source>
      <translation>&amp;Exportera sida...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Export a page to an SVG file</source>
      <translation>Exportera en sida till en SVG-fil</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewA3Landscape</name>
    <message>
      <location line="-314"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Insert new A3 landscape drawing</source>
      <translation>Infoga ny A3 landskap ritning</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewPage</name>
    <message>
      <location line="-133"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Insert new drawing</source>
      <translation>Sätt in ny ritning</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewView</name>
    <message>
      <location line="+166"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert view in drawing</source>
      <translation>Infoga vy i ritningen</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert a new View of a Part in the active drawing</source>
      <translation>Sätt in en ny vy av en Del i den aktiva ritningen</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOpen</name>
    <message>
      <location line="-202"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open SVG...</source>
      <translation>Öppna SVG...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open a scalable vector graphic</source>
      <translation>Öppna en skalbar vektorgrafik</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOpenBrowserView</name>
    <message>
      <location line="+294"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open &amp;browser view</source>
      <translation>Öppna we&amp;bbläsarvy</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Opens the selected page in a browser view</source>
      <translation>Öppnar den valda sidan i en webbläsarvy</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOrthoViews</name>
    <message>
      <location line="-49"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert orthographic views</source>
      <translation>Infoga ortografiska vyer</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert an orthographic projection of a part in the active drawing</source>
      <translation>Infoga en ortografisk projektion av en del i den aktiva ritningen</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingProjectShape</name>
    <message>
      <location line="+271"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Project shape...</source>
      <translation>Projekt former...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Project shape onto a user-defined plane</source>
      <translation>Projicera form på ett användardefinierat plan</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingSymbol</name>
    <message>
      <location line="-107"/>
      <source>Drawing</source>
      <translation type="unfinished">Ritning</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Symbol</source>
      <translation type="unfinished">&amp;Symbol</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Inserts a symbol from a svg file in the active drawing</source>
      <translation type="unfinished">Inserts a symbol from a svg file in the active drawing</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::DrawingView</name>
    <message>
      <location filename="../../DrawingView.cpp" line="+207"/>
      <source>&amp;Background</source>
      <translation>B&amp;akgrund</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>&amp;Outline</source>
      <translation>&amp;Kontur</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>&amp;Native</source>
      <translation>&amp;Nativ</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;OpenGL</source>
      <translation>&amp;OpenGL</translation>
    </message>
    <message>
      <location line="+3"/>
      <source>&amp;Image</source>
      <translation>&amp;Bild</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;High Quality Antialiasing</source>
      <translation>&amp;Högkvalitets kantutjämning</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Open SVG File</source>
      <translation>Öppna SVG-fil</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not open file '%1'.</source>
      <translation>Det gick inte att öppna fil '%1'.</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>&amp;Renderer</source>
      <translation>&amp;Renderare</translation>
    </message>
    <message>
      <location line="+55"/>
      <source>Export PDF</source>
      <translation>Exportera PDF</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>PDF file (*.pdf)</source>
      <translation>PDF-fil (*.pdf)</translation>
    </message>
    <message>
      <location line="+16"/>
      <source>Page sizes</source>
      <translation>Sidstorlekar</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>A0</source>
      <translation>A0</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>A1</source>
      <translation>A1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>A2</source>
      <translation>A2</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>A3</source>
      <translation>A3</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>A4</source>
      <translation>A4</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>A5</source>
      <translation>A5</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::TaskOrthoViews</name>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="+26"/>
      <source>Orthographic Projection</source>
      <translation>Ortografisk projektion</translation>
    </message>
    <message>
      <location line="+20"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+31"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+60"/>
      <source>Right click for axonometric settings</source>
      <translation type="unfinished">Right click for axonometric settings</translation>
    </message>
    <message>
      <location line="+106"/>
      <source>Top left x / y</source>
      <translation type="unfinished">Top left x / y</translation>
    </message>
    <message>
      <location line="+48"/>
      <source>Spacing dx / dy   </source>
      <translation type="unfinished">Spacing dx / dy   </translation>
    </message>
    <message>
      <location line="+71"/>
      <source> Axis out and right</source>
      <translation type="unfinished"> Axis out and right</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> Vertical tilt</source>
      <translation type="unfinished"> Vertical tilt</translation>
    </message>
    <message>
      <location line="+11"/>
      <location line="+200"/>
      <source>X +ve</source>
      <translation type="unfinished">X +ve</translation>
    </message>
    <message>
      <location line="-195"/>
      <location line="+75"/>
      <location line="+125"/>
      <source>Y +ve</source>
      <translation type="unfinished">Y +ve</translation>
    </message>
    <message>
      <location line="-195"/>
      <location line="+75"/>
      <location line="+125"/>
      <source>Z +ve</source>
      <translation type="unfinished">Z +ve</translation>
    </message>
    <message>
      <location line="-195"/>
      <location line="+200"/>
      <source>X -ve</source>
      <translation type="unfinished">X -ve</translation>
    </message>
    <message>
      <location line="-195"/>
      <location line="+70"/>
      <location line="+130"/>
      <source>Y -ve</source>
      <translation type="unfinished">Y -ve</translation>
    </message>
    <message>
      <location line="-195"/>
      <location line="+70"/>
      <location line="+130"/>
      <source>Z -ve</source>
      <translation type="unfinished">Z -ve</translation>
    </message>
    <message>
      <location line="-188"/>
      <source>Isometric</source>
      <translation type="unfinished">Isometric</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Dimetric</source>
      <translation type="unfinished">Dimetric</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Trimetric</source>
      <translation type="unfinished">Trimetric</translation>
    </message>
    <message>
      <location line="+8"/>
      <source> Scale</source>
      <translation type="unfinished"> Scale</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> View projection   </source>
      <translation type="unfinished"> View projection   </translation>
    </message>
    <message>
      <location line="+7"/>
      <source> Axis aligned up</source>
      <translation type="unfinished"> Axis aligned up</translation>
    </message>
    <message>
      <location line="+41"/>
      <location line="+23"/>
      <source>Flip</source>
      <translation type="unfinished">Flip</translation>
    </message>
    <message>
      <location line="-10"/>
      <source> Trimetric</source>
      <translation type="unfinished"> Trimetric</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Projection</source>
      <translation>Projektion</translation>
    </message>
    <message>
      <location line="+11"/>
      <source>Third Angle</source>
      <translation>Tredje vinkel</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>First Angle</source>
      <translation>Första vinkel</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>View from:</source>
      <translation type="unfinished">View from:</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>Axis aligned right:</source>
      <translation type="unfinished">Axis aligned right:</translation>
    </message>
    <message>
      <source>Primary View</source>
      <translation type="obsolete">Primär vy</translation>
    </message>
    <message>
      <source>Front</source>
      <translation type="obsolete">Front</translation>
    </message>
    <message>
      <source>Right</source>
      <translation type="obsolete">Höger</translation>
    </message>
    <message>
      <source>Back</source>
      <translation type="obsolete">Bakåt</translation>
    </message>
    <message>
      <source>Left</source>
      <translation type="obsolete">Vänster</translation>
    </message>
    <message>
      <source>Top</source>
      <translation type="obsolete">Topp</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation type="obsolete">Botten</translation>
    </message>
    <message>
      <source>- Rotate</source>
      <translation type="obsolete">- Rotera</translation>
    </message>
    <message>
      <source>90</source>
      <translation type="obsolete">90</translation>
    </message>
    <message>
      <source>180</source>
      <translation type="obsolete">180</translation>
    </message>
    <message>
      <source>270</source>
      <translation type="obsolete">270</translation>
    </message>
    <message>
      <location line="-514"/>
      <source>Primary view</source>
      <translation>Primär vy</translation>
    </message>
    <message>
      <location line="+16"/>
      <source>Secondary Views</source>
      <translation>Sekundär vy</translation>
    </message>
    <message>
      <location line="+72"/>
      <source>General</source>
      <translation>Allmänt</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Auto scale / position</source>
      <translation>Auto skala / position</translation>
    </message>
    <message>
      <location line="+15"/>
      <source>Scale</source>
      <translation>Skala</translation>
    </message>
    <message>
      <source>Primary x / y</source>
      <translation type="obsolete">Primär x / y</translation>
    </message>
    <message>
      <source>Secondary dx / dy</source>
      <translation type="obsolete">Sekundär dx / dy</translation>
    </message>
    <message>
      <location line="+125"/>
      <source>Show hidden</source>
      <translation>Visa dolda</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Show smooth</source>
      <translation>Visa utjämnat</translation>
    </message>
    <message>
      <location line="+11"/>
      <source>Axonometric</source>
      <translation>Axonometrisk</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::TaskProjection</name>
    <message>
      <location filename="../../TaskDialog.cpp" line="+49"/>
      <source>Visible sharp edges</source>
      <translation>Synliga vassa kanter</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Visible smooth edges</source>
      <translation>Synliga jämna kanter</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Visible sewn edges</source>
      <translation>Synliga sydda kanter</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Visible outline edges</source>
      <translation>Synliga kontur kanter</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Visible isoparameters</source>
      <translation>Synliga isoparametrar</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Hidden sharp edges</source>
      <translation>Dolda vassa kanter</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Hidden smooth edges</source>
      <translation>Dolda jämna kanter</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Hidden sewn edges</source>
      <translation>Dolda sydda kanter</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Hidden outline edges</source>
      <translation>Dolda kontur kanter</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Hidden isoparameters</source>
      <translation>Dolda isoparametrar</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Project shapes</source>
      <translation>Projekt former</translation>
    </message>
  </context>
  <context>
    <name>Drawing_NewPage</name>
    <message>
      <source>A0 landscape</source>
      <translation type="obsolete">Liggande A0</translation>
    </message>
    <message>
      <source>Insert new A0 landscape drawing</source>
      <translation type="obsolete">Infoga ny liggande A0 ritning</translation>
    </message>
    <message>
      <source>A1 landscape</source>
      <translation type="obsolete">Liggande A1</translation>
    </message>
    <message>
      <source>Insert new A1 landscape drawing</source>
      <translation type="obsolete">Infoga ny liggande A1 ritning</translation>
    </message>
    <message>
      <source>A2 landscape</source>
      <translation type="obsolete">Liggande A2</translation>
    </message>
    <message>
      <source>Insert new A2 landscape drawing</source>
      <translation type="obsolete">Infoga ny liggande A2 ritning</translation>
    </message>
    <message>
      <source>A3 landscape</source>
      <translation type="obsolete">Liggande A3</translation>
    </message>
    <message>
      <source>Insert new A3 landscape drawing</source>
      <translation type="obsolete">Infoga ny A3 landskap ritning</translation>
    </message>
    <message>
      <source>A4 landscape</source>
      <translation type="obsolete">Liggande A4</translation>
    </message>
    <message>
      <source>Insert new A4 landscape drawing</source>
      <translation type="obsolete">Infoga ny liggande A4 ritning</translation>
    </message>
    <message>
      <source>Insert new A%1 landscape drawing</source>
      <translation type="obsolete">Infoga ny A%1 landskaps ritning</translation>
    </message>
    <message>
      <source>A%1 landscape</source>
      <translation type="obsolete">A%1 landskap</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-298"/>
      <source>Landscape</source>
      <translation type="unfinished">Landscape</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Portrait</source>
      <translation type="unfinished">Portrait</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>%1%2 %3</source>
      <translation type="unfinished">%1%2 %3</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Insert new %1%2 %3 drawing</source>
      <translation type="unfinished">Insert new %1%2 %3 drawing</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location line="-124"/>
      <location line="+426"/>
      <source>Choose an SVG file to open</source>
      <translation>Välj en SVG fil att öppna</translation>
    </message>
    <message>
      <location filename="../../AppDrawingGuiPy.cpp" line="+64"/>
      <location line="+30"/>
      <location filename="../../ViewProviderPage.cpp" line="+139"/>
      <source>Drawing viewer</source>
      <translation>Ritningsvisare</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-425"/>
      <location line="+426"/>
      <source>Scalable Vector Graphics (*.svg *.svgz)</source>
      <translation>Skalbar vektorgrafik (*.svg *.svgz)</translation>
    </message>
    <message>
      <location line="-227"/>
      <location line="+51"/>
      <location line="+45"/>
      <location line="+177"/>
      <source>Wrong selection</source>
      <translation>Fel val</translation>
    </message>
    <message>
      <location line="-272"/>
      <location line="+51"/>
      <source>Select a Part object.</source>
      <translation>Välj ett Del objekt.</translation>
    </message>
    <message>
      <location line="-45"/>
      <location line="+51"/>
      <location line="+76"/>
      <location line="+45"/>
      <location line="+42"/>
      <source>No page to insert</source>
      <translation>Ingen sida att infoga</translation>
    </message>
    <message>
      <location line="-213"/>
      <location line="+127"/>
      <location line="+45"/>
      <location line="+42"/>
      <source>Create a page to insert.</source>
      <translation>Skapa en sida att infoga.</translation>
    </message>
    <message>
      <location line="-163"/>
      <source>Create a page to insert views into.</source>
      <translation>Skapa en sida att infoga vyer till.</translation>
    </message>
    <message>
      <location line="+38"/>
      <location line="+177"/>
      <source>Select one Page object.</source>
      <translation>Välj ett sidobjekt.</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>SVG(*.svg)</source>
      <translation>SVG (*.svg)</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>All Files (*.*)</source>
      <translation>Alla filer (*.*)</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Export page</source>
      <translation>Exportera sida</translation>
    </message>
    <message>
      <location filename="../../ViewProviderPage.cpp" line="-27"/>
      <source>Show drawing</source>
      <translation>Visa ritning</translation>
    </message>
    <message>
      <source>Front</source>
      <translation type="obsolete">Front</translation>
    </message>
    <message>
      <source>Back</source>
      <translation type="obsolete">Bakåt</translation>
    </message>
    <message>
      <source>Right</source>
      <translation type="obsolete">Höger</translation>
    </message>
    <message>
      <source>Left</source>
      <translation type="obsolete">Vänster</translation>
    </message>
    <message>
      <source>Top</source>
      <translation type="obsolete">Topp</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation type="obsolete">Botten</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.cpp" line="+45"/>
      <location line="+908"/>
      <source>Make axonometric...</source>
      <translation type="unfinished">Make axonometric...</translation>
    </message>
    <message>
      <location line="-907"/>
      <location line="+908"/>
      <source>Edit axonometric settings...</source>
      <translation type="unfinished">Edit axonometric settings...</translation>
    </message>
    <message>
      <location line="-907"/>
      <location line="+908"/>
      <source>Make orthographic</source>
      <translation type="unfinished">Make orthographic</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
  </context>
</TS>
